/*!	\file
	AlbaLynx error codes <br><br>

	AlbaLynx Library <br>
	Copyright 2009-2010(c) Mikhail Meshchangin (wolfhound512 -- www.albalynx.com)
*/

#ifndef __ALBALYNX_ERROR_CODES__
#define __ALBALYNX_ERROR_CODES__

/*! \addtogroup gp_const
	@{ */
/*!	\if ENG
	\defgroup gp_errors Error codes
	\elseif RUS
	\defgroup gp_errors Коды ошибок
	\endif
	@{ */
//---------------------------------------------------------------------
//	------------				Error levels			------------
//---------------------------------------------------------------------
/*!	\if ENG
	\brief Levels of error messages.
	\elseif RUS
	\brief Уровни сообщений об ошибках.
	\endif */
enum ALERROR_LEVEL {
/*!	\if ENG
	\brief This flag can be used to disable the output of system messages.
	\elseif RUS
	\brief Этот флаг может быть использован для отключения вывода системных сообщений.
	\endif */
	ALLEVEL_NONE = 0,
/*!	\if ENG
	\brief [N/A] Debug messages.
	\elseif RUS
	\brief [N/A] Сообщения для отладки.
	\endif */
	ALLEVEL_DEBUG = 1,
/*!	\if ENG
	\brief [N/A] Notification of significant changes in the GUI (create / delete elements, etc.).
	\elseif RUS
	\brief [N/A] Уведомления о заметных изменениях в GUI (создание\удаление элементов и пр.).
	\endif */
	ALLEVEL_NOTICE = 2,
/*!	\if ENG
	\brief Warning about not correct actions, about the transfer of invalid parameters and about errors in template files.
	\elseif RUS
	\brief Предупреждения о не корректных действиях, о передаче недопустимых параметров, ошибках в файлах шаблонов.
	\endif */
	ALLEVEL_WARNING = 4,
/*!	\if ENG
	\brief Error messages, after which work can be continued.
	\elseif RUS
	\brief Сообщения об ошибках, работа после которых может быть продолжена.
	\endif */
	ALLEVEL_ERROR = 8,
/*!	\if ENG
	\brief Critical errors leading to termination.
	\elseif RUS
	\brief Критические ошибки ведущие к завершению работы программы.
	\endif */
	ALLEVEL_FATAL = 16,
/*!	\if ENG
	\brief This flag can be used to set the observer: respond to all levels of messages.
	\elseif RUS
	\brief Этот флаг может использоваться для установки обработчику: реагировать на все виды сообщений.
	\endif */
	ALLEVEL_ALL = 255
};
//---------------------------------------------------------------------
//	------------				Error codes				------------
//---------------------------------------------------------------------
/*!	\cond SKIP */
/* Коды ошибок СИСТЕМАТИЗИРОВАТЬ!!! */
/* AlbaLynx trial */
#define ALERROR_ALBALYNX_TRIAL 1
/* Файл не найден */
#define ALERROR_FILE_NOT_FOUND 404
/* Ошибка, появление которой невозможно иначе как по воле дьявола */
#define ALERROR_IMPOSSIBLE_ERROR 666
/* Не удалось загрузить движек */
#define ALERROR_ENGINE_FAIL 998
/* Не удалось загрузить FastImageXors */
#define ALERROR_FASTIMAGE_FAIL 999
/* Указаный родительский элемент не существует */
#define ALERROR_PARENT_DONT_EXIST 1000
/* Шаблон с указаным именем не существует */
#define ALERROR_TEMPLATE_NOT_FOUND 1001
/* В шаблоне отсутствует одна из обязательных зон для этого элемнта */
#define ALERROR_ZONE_NOT_FOUND 1002
/* Повторяющееся имя */
#define ALERROR_DUPLICATE_NAME 1005
/* Неудалось инициализировать FreeType */
#define ALERROR_FREETYPE_INIT_FAIL 1006
/* Неудалось загрузить шрифт */
#define ALERROR_FILE_NOT_LOADED 1022
/* Неудалось загрузить шрифт */
#define ALERROR_FONT_NOT_LOADED 1007
/* Неудалось загрузить шрифт */
#define ALERROR_IMAGE_NOT_LOADED 10011
/* Не указан один из обязательных параметров */
#define ALERROR_REQUIRED_PARAMETER_MISSING 1008
/* В шаблоне отсутствет один из обязательных примитивов для этого элемнта */
#define ALERROR_PRIMITIVE_NOT_FOUND 1009
/* При создании примитива 'Texture' указано несуществующее изображение */
#define ALERROR_IMAGE_NOT_EXIST 1010
/* При создании примитива 'Text' т.к. не указан шрифт и нет шрифта по умолчанию */
#define ALERROR_FONT_NOT_EXIST 1012
/* Неверный тип родительского или дочернего элемента, не удалось добавить элемент в родительский список */
#define ALERROR_WRONG_PARENT_OR_CHILD 1013
/* Элемент не существует */
#define ALERROR_ELEMENT_NOT_EXIST 1014
/* Неверный тип элемента */
#define ALERROR_WRONG_ELEMENT_TYPE 1015
/* Не выполнена функция FastImage::StartDraw() */
#define ALERROR_FASTIMAGE_DRAW_NOT_STARTED 1016
/* Не удалось открыть буфер обмена */
#define ALERROR_CLIPBOARD_OPEN_FAIL 1018
/* Не удалось выделить память для буфера обмена */
#define ALERROR_CLIPBOARD_MEMALLOC_FAIL 1019
/* Дочерний элемент не найден в родительском списке */
#define ALERROR_CHILD_NOT_FOUND 1020
/* Недоступное действие */
#define ALERROR_UNAVAILABLE_ACTION 1021
/* Не удалось добавить элемент в список */
#define ALERROR_STL_INSERT_FAIL 1022
/* Не удалось загрузить XML файл */
#define ALERROR_XML_FILE_ERROR 1023
/* Не верный тип примитива. Данная операция не может быть выполнена для этого типа примитивов */
#define ALERROR_WRONG_PRIMITIVE_TYPE 1024
/* Ошибка одного из слушателей оброботчика исключений */
#define ALERROR_OBSERVER_FAIL 1025
/* Не корректный (нулевой) указатель на строку */
#define ALERROR_INVALID_CHAR_POINTER 1026
/* Наблюдатель не существует */
#define ALERROR_OBSERVER_NOT_EXIST 1027
/* Не корректный указатель на функцию */
#define ALERROR_INVALID_FUNCTION_POINTER 1028
/* Не удалось создать элемент */
#define ALERROR_ELEMENT_CREATION_FAIL 1029
/* Не удалось создать дочерний элемент */
#define ALERROR_CHILD_CREATION_FAIL 1030
/* Системная ошибка. Не верный или неожидаемый тип элемента. */
#define ALERROR_SYSTEM_WRONG_ELEMENT_TYPE 2001
/* Системная ошибка. Отсутствует родительский элемент. */
#define ALERROR_SYSTEM_PARENT_ABSENT 2002
/* Системная ошибка. Несовпадение типов. */
//#define ALERROR_SYSTEM_PARENT_ABSENT 2002
/*!	\endcond */

/*!	@} */
/*!	@} */

#endif /*__ALBALYNX_ERROR_CODES__*/